@@ -287,7 +287,7 @@ class PreferencesManager(component.Component):
 
     def _on_set_dht(self, key, value):
         log.debug("dht value set to %s", value)
-        state_file = deluge.common.get_default_config_dir("dht.state")
+        state_file = deluge.configmanager.get_config_dir("dht.state")
         if value:
             state = None
             try:
@@ -468,7 +468,7 @@ class PreferencesManager(component.Component):
                 72 * 60 * 60 * 1000, self._on_new_release_check, "new_release_check", True)
         else:
             if self.new_release_timer:
-                gobject.source.remove(self.new_release_timer)
+                gobject.source_remove(self.new_release_timer)
 
     def _on_set_proxies(self, key, value):
         for k, v in value.items():
