@@ -189,13 +189,23 @@ class Torrent:
             self.trackers = []
             # Create a list of trackers
             for value in self.handle.trackers():
-                tracker = {}
-                tracker["url"] = value.url
-                tracker["tier"] = value.tier
+                if lt.version_minor < 15:
+                    tracker = {}
+                    tracker["url"] = value.url
+                    tracker["tier"] = value.tier
+                else:
+                    tracker = value
                 self.trackers.append(tracker)
 
         # Various torrent options
-        self.handle.resolve_countries(True)
+        # XXX: Disable resolve_countries if using a 64-bit long and on lt 0.14.2 or lower.
+        # This is a workaround for a bug in lt.
+        import sys
+        if sys.maxint > 0xFFFFFFFF and lt.version < "0.14.3.0":
+            self.handle.resolve_countries(False)
+        else:
+            self.handle.resolve_countries(True)
+
         self.set_options(self.options)
 
         # Status message holds error info about the torrent
@@ -288,6 +298,12 @@ class Torrent:
     def set_remove_at_ratio(self, remove_at_ratio):
         self.options["remove_at_ratio"] = remove_at_ratio
 
+    def set_move_on_completed(self, move_completed):
+        self.options["move_completed"] = move_completed
+
+    def set_move_on_completed_path(self, move_completed_path):
+        self.options["move_completed_path"] = move_completed_path
+
     def set_file_priorities(self, file_priorities):
         if len(file_priorities) != len(self.files):
             log.debug("file_priorities len != num_files")
@@ -323,26 +339,32 @@ class Torrent:
         if trackers == None:
             trackers = []
             for value in self.handle.trackers():
-                tracker = {}
-                tracker["url"] = value.url
-                tracker["tier"] = value.tier
+                if lt.version_minor < 15:
+                    tracker = {}
+                    tracker["url"] = value.url
+                    tracker["tier"] = value.tier
+                else:
+                    tracker = value
                 trackers.append(tracker)
+
             self.trackers = trackers
             return
 
         log.debug("Setting trackers for %s: %s", self.torrent_id, trackers)
         tracker_list = []
 
-        for tracker in trackers:
-            new_entry = lt.announce_entry(tracker["url"])
-            new_entry.tier = tracker["tier"]
-            tracker_list.append(new_entry)
-
-        self.handle.replace_trackers(tracker_list)
+        if lt.version_minor < 15:
+            for tracker in trackers:
+                new_entry = lt.announce_entry(tracker["url"])
+                new_entry.tier = tracker["tier"]
+                tracker_list.append(new_entry)
+            self.handle.replace_trackers(tracker_list)
+        else:
+            self.handle.replace_trackers(trackers)
 
         # Print out the trackers
-        for t in self.handle.trackers():
-            log.debug("tier: %s tracker: %s", t.tier, t.url)
+        #for t in self.handle.trackers():
+        #    log.debug("tier: %s tracker: %s", t.tier, t.url)
         # Set the tracker list in the torrent object
         self.trackers = trackers
         if len(trackers) > 0:
@@ -473,7 +495,11 @@ class Torrent:
     def get_peers(self):
         """Returns a list of peers and various information about them"""
         ret = []
-        peers = self.handle.get_peer_info()
+        try:
+            peers = self.handle.get_peer_info()
+        except IndexError, e:
+            log.error("There was an error getting peer info! This may be a bug in libtorrent.  Please upgrade to libtorrent >= 0.14.3.")
+            return ret
 
         for peer in peers:
             # We do not want to report peers that are half-connected
@@ -626,10 +652,11 @@ class Torrent:
 
         def ti_name():
             if self.handle.has_metadata():
+                name = self.torrent_info.file_at(0).path.split("/", 1)[0]
                 try:
-                    return self.torrent_info.name().decode("utf8", "ignore")
+                    return name.decode("utf8", "ignore")
                 except UnicodeDecodeError:
-                    return self.torrent_info.name()
+                    return name
 
             return self.torrent_id
         def ti_priv():
@@ -693,7 +720,13 @@ class Torrent:
         self.handle.set_upload_limit(int(self.max_upload_speed * 1024))
         self.handle.set_download_limit(int(self.max_download_speed * 1024))
         self.handle.prioritize_files(self.file_priorities)
-        self.handle.resolve_countries(True)
+        # XXX: Disable resolve_countries if using a 64-bit long and on lt 0.14.2 or lower.
+        # This is a workaround for a bug in lt.
+        import sys
+        if sys.maxint > 0xFFFFFFFF and lt.version < "0.14.3.0":
+            self.handle.resolve_countries(False)
+        else:
+            self.handle.resolve_countries(True)
 
     def pause(self):
         """Pause this torrent"""
