@@ -32,9 +32,6 @@
 #    statement from all source files in the program, then also delete it here.
 #
 
-#
-
-
 import gtk, gtk.glade
 import gobject
 import gettext
@@ -122,7 +119,7 @@ class FilesTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(200)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -135,7 +132,7 @@ class FilesTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(50)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -148,7 +145,7 @@ class FilesTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(100)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -164,7 +161,7 @@ class FilesTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(100)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -741,8 +738,12 @@ class FilesTab(Tab):
                 # This means that a folder by this name already exists
                 self.reparent_iter(self.treestore.iter_children(old_folder_iter), new_folder_iter)
             else:
-                new_folder_iter = self.get_iter_at_path("/".join(new_split[:-1]) + "/")
-                self.reparent_iter(old_folder_iter, new_folder_iter)
+                parent = old_folder_iter_parent
+                for ns in new_split[:-1]:
+                    parent = self.treestore.append(parent, [ns + "/", 0, "", 0, 0, -1, gtk.STOCK_DIRECTORY])
+
+                self.treestore[old_folder_iter][0] = new_split[-1] + "/"
+                self.reparent_iter(old_folder_iter, parent)
 
             # We need to check if the old_folder_iter_parent no longer has children
             # and if so, we delete it
