@@ -32,9 +32,6 @@
 #    statement from all source files in the program, then also delete it here.
 #
 
-#
-
-
 import gtk, gtk.glade
 import os.path
 import cPickle
@@ -73,7 +70,7 @@ class PeersTab(Tab):
         self.listview = glade.get_widget("peers_listview")
         self.listview.connect("button-press-event", self._on_button_press_event)
         # country pixbuf, ip, client, downspeed, upspeed, country code, int_ip, seed/peer icon, progress
-        self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, str, int, int, str, gobject.TYPE_UINT, gtk.gdk.Pixbuf, float)
+        self.liststore = gtk.ListStore(gtk.gdk.Pixbuf, str, str, int, int, str, float, gtk.gdk.Pixbuf, float)
         self.cached_flag_pixbufs = {}
 
         self.seed_pixbuf = gtk.gdk.pixbuf_new_from_file(deluge.common.get_pixmap("seeding16.png"))
@@ -91,7 +88,7 @@ class PeersTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(20)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -107,7 +104,7 @@ class PeersTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(100)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -120,7 +117,7 @@ class PeersTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(100)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -133,7 +130,7 @@ class PeersTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(100)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -146,7 +143,7 @@ class PeersTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(50)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -159,7 +156,7 @@ class PeersTab(Tab):
         column.set_clickable(True)
         column.set_resizable(True)
         column.set_expand(False)
-        column.set_min_width(10)
+        column.set_min_width(50)
         column.set_reorderable(True)
         self.listview.append_column(column)
 
@@ -308,8 +305,17 @@ class PeersTab(Tab):
                 # Peer is not in list so we need to add it
 
                 # Create an int IP address for sorting purposes
-                ip_int = sum([int(byte) << shift
-                    for byte, shift in izip(peer["ip"].split(":")[0].split("."), (24, 16, 8, 0))])
+                if peer["ip"].count(":") == 1:
+                    # This is an IPv4 address
+                    ip_int = sum([int(byte) << shift
+                        for byte, shift in izip(peer["ip"].split(":")[0].split("."), (24, 16, 8, 0))])
+                else:
+                    # This is an IPv6 address
+                    import socket
+                    import binascii
+                    # Split out the :port
+                    ip = ":".join(peer["ip"].split(":")[:-1])
+                    ip_int = long(binascii.hexlify(socket.inet_pton(socket.AF_INET6, ip)), 16)
 
                 if peer["seed"]:
                     icon = self.seed_pixbuf
@@ -323,7 +329,7 @@ class PeersTab(Tab):
                     peer["down_speed"],
                     peer["up_speed"],
                     peer["country"],
-                    ip_int,
+                    float(ip_int),
                     icon,
                     peer["progress"]])
 
