@@ -184,8 +184,19 @@ namespace libtorrent
 			copy_file(old_path, new_path);
 		}
 #ifndef BOOST_NO_EXCEPTIONS
-		} catch (std::exception& e) { ec = error_code(errno, get_posix_category()); }
-#endif
+		}
+#if BOOST_VERSION >= 103500
+		catch (boost::system::system_error& e)
+		{
+			ec = e.code();
+		}
+#else
+		catch (boost::filesystem::filesystem_error& e)
+		{
+			ec = error_code(e.system_error(), get_system_category());
+		}
+#endif // BOOST_VERSION
+#endif // BOOST_NO_EXCEPTIONS
 	}
 
 	template <class Path>
@@ -325,6 +336,7 @@ namespace libtorrent
 			TORRENT_ASSERT(m_save_path.is_complete());
 		}
 
+		bool has_any_file();
 		bool rename_file(int index, std::string const& new_filename);
 		bool release_files();
 		bool delete_files();
@@ -339,6 +351,7 @@ namespace libtorrent
 		bool write_resume_data(entry& rd) const;
 		sha1_hash hash_for_slot(int slot, partial_hash& ph, int piece_size);
 
+		void delete_one_file(std::string const& p);
 		int read_impl(char* buf, int slot, int offset, int size, bool fill_zero);
 
 		~storage()
@@ -445,13 +458,21 @@ namespace libtorrent
 			}
 #ifndef BOOST_NO_EXCEPTIONS
 			}
-			catch (std::exception& e)
+#if BOOST_VERSION >= 103500
+			catch (boost::system::system_error& e)
 			{
-				set_error(m_save_path / file_iter->path
-					, error_code(errno, get_posix_category()));
+				set_error(m_save_path / file_iter->path, e.code());
 				return true;
 			}
-#endif
+#else
+			catch (boost::filesystem::filesystem_error& e)
+			{
+				set_error(m_save_path / file_iter->path
+					, error_code(e.system_error(), get_system_category()));
+				return true;
+			}
+#endif // BOOST_VERSION
+#endif // BOOST_NO_EXCEPTIONS
 		}
 		std::vector<boost::uint8_t>().swap(m_file_priority);
 		// close files that were opened in write mode
@@ -459,6 +480,47 @@ namespace libtorrent
 		return false;
 	}
 
+	bool storage::has_any_file()
+	{
+		file_storage::iterator i = m_files.begin();
+		file_storage::iterator end = m_files.end();
+
+		for (; i != end; ++i)
+		{
+			bool file_exists = false;
+			fs::path f = m_save_path / i->path;
+#ifndef BOOST_NO_EXCEPTIONS
+			try
+			{
+#endif
+#if TORRENT_USE_WPATH
+				fs::wpath wf = safe_convert(f.string());
+				file_exists = exists(wf);
+#else
+				file_exists = exists(f);
+#endif
+#ifndef BOOST_NO_EXCEPTIONS
+			}
+#if BOOST_VERSION >= 103500
+			catch (boost::system::system_error& e)
+			{
+				set_error(f, e.code());
+				return false;
+			}
+#else
+			catch (boost::filesystem::filesystem_error& e)
+			{
+				set_error(f, error_code(e.system_error(), get_system_category()));
+				return false;
+			}
+#endif // BOOST_VERSION
+#endif // BOOST_NO_EXCEPTIONS
+			if (file_exists && i->size > 0)
+				return true;
+		}
+		return false;
+	}
+
 	bool storage::rename_file(int index, std::string const& new_filename)
 	{
 		if (index < 0 || index >= m_files.num_files()) return true;
@@ -502,12 +564,14 @@ namespace libtorrent
 			set_error(old_name, e.code());
 			return true;
 		}
-#endif
-		catch (std::exception& e)
+#else
+		catch (boost::filesystem::filesystem_error& e)
 		{
-			set_error(old_name, error_code(errno, get_posix_category()));
+			set_error(old_name, error_code(e.system_error()
+				, get_system_category()));
 			return true;
 		}
+#endif // BOOST_VERSION
 #endif
 		return false;
 	}
@@ -519,15 +583,40 @@ namespace libtorrent
 		return false;
 	}
 
+	void storage::delete_one_file(std::string const& p)
+	{
+#if TORRENT_USE_WPATH
+#ifndef BOOST_NO_EXCEPTIONS
+		try
+#endif
+		{ fs::remove(safe_convert(p)); }
+#ifndef BOOST_NO_EXCEPTIONS
+#if BOOST_VERSION >= 103500
+		catch (boost::system::system_error& e)
+		{
+			set_error(p, e.code());
+		}
+#else
+		catch (boost::filesystem::filesystem_error& e)
+		{
+			set_error(p, error_code(e.system_error(), get_system_category()));
+		}
+#endif // BOOST_VERSION
+#endif // BOOST_NO_EXCEPTIONS
+#else // TORRENT_USE_WPATH
+		if (std::remove(p.c_str()) != 0 && errno != ENOENT)
+		{
+			set_error(p, error_code(errno, get_posix_category()));
+		}
+#endif
+	}
+
 	bool storage::delete_files()
 	{
 		// make sure we don't have the files open
 		m_pool.release(this);
 		buffer().swap(m_scratch_buffer);
 
-		int error = 0;
-		std::string error_file;
-
 		// delete the files from disk
 		std::set<std::string> directories;
 		typedef std::set<std::string>::iterator iter_t;
@@ -543,21 +632,7 @@ namespace libtorrent
 				std::pair<iter_t, bool> ret = directories.insert((m_save_path / bp).string());
 				bp = bp.branch_path();
 			}
-#if TORRENT_USE_WPATH
-			try
-			{ fs::remove(safe_convert(p)); }
-			catch (std::exception& e)
-			{
-				error = errno;
-				error_file = p;
-			}
-#else
-			if (std::remove(p.c_str()) != 0 && errno != ENOENT)
-			{
-				error = errno;
-				error_file = p;
-			}
-#endif
+			delete_one_file(p);
 		}
 
 		// remove the directories. Reverse order to delete
@@ -566,29 +641,10 @@ namespace libtorrent
 		for (std::set<std::string>::reverse_iterator i = directories.rbegin()
 			, end(directories.rend()); i != end; ++i)
 		{
-#if TORRENT_USE_WPATH
-			try
-			{ fs::remove(safe_convert(*i)); }
-			catch (std::exception& e)
-			{
-				error = errno;
-				error_file = *i;
-			}
-#else
-			if (std::remove(i->c_str()) != 0 && errno != ENOENT)
-			{
-				error = errno;
-				error_file = *i;
-			}
-#endif
+			delete_one_file(*i);
 		}
 
-		if (error)
-		{
-			m_error = error_code(error, get_posix_category());
-			m_error_file.swap(error_file);
-			return true;
-		}
+		if (error()) return true;
 		return false;
 	}
 
@@ -1671,51 +1727,27 @@ namespace libtorrent
 
 	int piece_manager::check_no_fastresume(std::string& error)
 	{
-		file_storage::iterator i = m_files.begin();
-		file_storage::iterator end = m_files.end();
+		bool has_files = m_storage->has_any_file();
 
-		for (; i != end; ++i)
+		if (m_storage->error())
+			return fatal_disk_error;
+
+		if (has_files)
 		{
-			bool file_exists = false;
-			fs::path f = m_save_path / i->path;
-#ifndef BOOST_NO_EXCEPTIONS
-			try
+			m_state = state_full_check;
+			m_piece_to_slot.clear();
+			m_piece_to_slot.resize(m_files.num_pieces(), has_no_slot);
+			m_slot_to_piece.clear();
+			m_slot_to_piece.resize(m_files.num_pieces(), unallocated);
+			if (m_storage_mode == storage_mode_compact)
 			{
-#endif
-#if TORRENT_USE_WPATH
-				fs::wpath wf = safe_convert(f.string());
-				file_exists = exists(wf);
-#else
-				file_exists = exists(f);
-#endif
-#ifndef BOOST_NO_EXCEPTIONS
-			}
-			catch (std::exception& e)
-			{
-				error = f.string();
-				error += ": ";
-				error += e.what();
-				TORRENT_ASSERT(!error.empty());
-				return fatal_disk_error;
-			}
-#endif
-			if (file_exists && i->size > 0)
-			{
-				m_state = state_full_check;
-				m_piece_to_slot.clear();
-				m_piece_to_slot.resize(m_files.num_pieces(), has_no_slot);
-				m_slot_to_piece.clear();
-				m_slot_to_piece.resize(m_files.num_pieces(), unallocated);
-				if (m_storage_mode == storage_mode_compact)
-				{
-					m_unallocated_slots.clear();
-					m_free_slots.clear();
-				}
-				TORRENT_ASSERT(int(m_piece_to_slot.size()) == m_files.num_pieces());
-				return need_full_check;
+				m_unallocated_slots.clear();
+				m_free_slots.clear();
 			}
+			TORRENT_ASSERT(int(m_piece_to_slot.size()) == m_files.num_pieces());
+			return need_full_check;
 		}
-	
+
 		if (m_storage_mode == storage_mode_compact)
 		{
 			// in compact mode without checking, we need to
@@ -1768,6 +1800,8 @@ namespace libtorrent
 		INVARIANT_CHECK;
 
 		TORRENT_ASSERT(m_files.piece_length() > 0);
+		
+		m_current_slot = 0;
 
 		// if we don't have any resume data, return
 		if (rd.type() == lazy_entry::none_t) return check_no_fastresume(error);
@@ -2195,7 +2229,10 @@ namespace libtorrent
 #else
 				&& m_storage->error() != error_code(ENOENT, get_posix_category()))
 #endif
+			{
+				m_piece_data.clear();
 				return -1;
+			}
 			return 1;
 		}
 
